@@ -6,6 +6,10 @@ import codecs
 import os.path
 import inflection
 
+import logging
+logger = logging.getLogger(__name__)
+
+
 import python_jsonschema_objects.classbuilder as classbuilder
 from python_jsonschema_objects.validators import ValidationError
 import python_jsonschema_objects.util
